# Name

pacboy.json - Pacboy configuration file


# Description
The Pacboy configuration file is a plain JSON file. By default it is located at `/etc/pacboy/config-pacboy.json`. The main object is a dictionary where each key is considered a section below.


# Sections
Note that all section names are in lower case in the file. Upper case may appear in the man page during automatic conversion of the markdown file. For example, "aria2" should appear in the configuration file, not "ARIA2".

## aria2

Configuration for the Aria2 RPC server(s) that will be used to download packages using parallel and segmented downloads. Running servers will be detected and used, otherwise servers will be started and stopped as needed.

By default, launched servers are restricted to localhost for security reasons. Some operations will require root privileges to save files in restricted directories (e.g. the Pacman sync database and cache directories).

command
:   A list representing the aria2c command and arguments to use when launching the download server. By default this includes the `--rpc-listen-all=false` option to restrict the server to listening on localhost. For a full description of the options, see the Aria2 documentation.

server
:   A dictionary specifying the port and token to use for server with non-root privileges: `{"port": 6800, "token": null}`. Leave "token" as null to use a random token each time the server is launched.


## build

pre-install
:   A boolean. If True, Pacboy will install all target binary packages before building other packages, including binary packages in the build list. Without this option, packages will be installed in sequential groups between builds as required by the dependency tree. The reason for this option is that the sequential operation may replace "pacman -Su" with multiple "pacman -S <pkgname> <pkgname> ..." commands. If for some reason the installation should not be split this way, the option is necessary. There is also a matching command-line option.

snippets
:   A dictionary with the following keys:
    * build: A path to the default build snippet. See `pacboy --pb-snippet-help` for details.
    * custom build: A list of pairs of regular expressions and paths. The regular expressions will be matched against fully qualified pkgnames (e.g. "core/pacman") in order. If one matches then the associated snippet will be used for that package. For example, `"custom build":[["-git$", "/path/to/git/snippet"], ["-hg$", "/path/to/mercurial/snippet"]]` could be used to assign a custom snippet for building all Git packages and another custom snippet for all Mercurial package. This can be used to apply patches, select other branches, change configuration options, etc. See `pacboy --pb-snippet-help` for details.
    * prologue: The beginning of the build script. This should specify the hashbang on the first line.
    * epilogue: A script to concatenate to the end of the build script. This may be `null`.

user
:   The system user as which to run the build scripts. If `null`, Pacboy will check if the environment variable `SUDO_USER` is set and use it to build if it is.

VCS download command
:   A list giving the download command for VCS sources in PKGBUILDs. By default, this uses a supplied script that internally uses makepkg's backend to ensure compatibility with makepkg: `["makepkg-download_vcs_sources", "-o", "%OUTDIR%", "%URI%"]`. This will be inserted directly into the build snippets so all variables supported by the snippets are supported in this command.


VCS patterns
:   A list of regular expressions for matching VCS package. This is used to determine build targets with `pacboy --pb-rebuild-vcs`.


## env

A dictionary of values shared to load into the environment object passed to the extensions.

ttl
:   Time-to-live of cached data.

pacserve
:   The URL of a Pacserve server to use, e.g. `http://localhost:15678`. Either omit this or set it to `null` if there is no server.


## foreign config

A dictionary of configuration objects for enabled extensions. A class's configuration object should appear under its own fully qualified name to avoid cluttering the namespace, e.g. `"XCPF.PacmanRepoWrapper.OfficialBuildExtender": {}`.


## packages

build
:   A list of regular expressions that will be matched against qualified target pkgnames (e.g. "core/foo"). If there is a match, the package will be built if possible. For example, to always build the kernel when doing a system upgrade, use `["^core/kernel$"]`. This can be combined with a custom build snippet to applied custom options and patches to the kernel.

nobuild
:   The same as build but packages that match will never be built.

repo associations
:   A list of regular expression-reponame pairs that can be used to always install a package from a target repo. For example, if package "foo" exists in the core repo but you would like to always install it from a custom repo "bar" regardless of the repo order, you could use `["^foo", "bar"]`. These patterns are matched against the unqualified pkgname if it appears in the build targets. Explicitly passing a qualified pkgname on the command-line will override this, e.g. "pacman -S core/foo" will install "foo" from core even if there is a matching pattern.


## pacman

config
:   The path to the default pacman configuration file.

path
:   The path to the pacman executable.



## repos

enabled
:   A list of repos to enable. This also configures the order in which package targets are satisfied. `*` will be expanded to all of the repos enabled in the Pacman configuration file. For example, to add all of the currently enabled Pacman repos and the AUR, use `["*", "AUR"]`.

repo wrapper factories
:   A list of lists to enable non-Pacman repositories. Each sublist begins with the fully qualified Python name of a subclass of `RepoWrapperFactory` followed by the names of the repos that it supports. For example, AUR support can be enabled with `["AUR.AurPkg.AurRepoWrapperFactory", "AUR"]`.

build extender factories
:   A list of lists to add build support to Pacman repositories. Each sublist begins with the fully qualified Python name of a subclass of `BuildExtenderFactory` followed by the names of the repos that it supports. For example, build support can be added to the official Pacman repos with `["XCPF.Repo.OfficialBuildExtenderFactory", "core", "extra", "community", "multilib"]`.

usage
:   An extension of the `Usage` directive from the Pacman configuration file (see `man pacman.conf`) to non-Pacman repos. This is a dictionary of repo names mapped to lists, the elements of which are the same as Pacman's `Usage` parameters. For example. to restrict AUR usage to searches, use `"AUR": ["Search"]`. For Pacman repos, this setting overrides the setting in the Pacman configuration file if present.


## sudo

command
:   A list specifying the command to use when invoking sudo. By default, `["/usr/bin/sudo"]`
